@@ -15,15 +15,15 @@
 #include <QAction>
 #include <KToggleAction>
 #include <KActionCollection>
-#include <KStandardGameAction>
+#include <KGameStandardAction>
 #include <QStatusBar>
 
-#include <KgDifficulty>
-#include <KgThemeSelector>
+#include <KGameDifficulty>
+#include <KGameThemeSelector>
 #include <KGameRenderer>
 #include <KScoreDialog>
 #include <KGameClock>
-#include <KgSound>
+#include <KGameSound>
 
 #include <ctime>
 #include <cmath>
@@ -77,14 +77,14 @@ MainWindow::MainWindow(QWidget *parent)
     statusBar()->insertPermanentWidget(1, m_timeLabel, 1);
 
     // Difficulty
-    Kg::difficulty()->addStandardLevelRange(
-        KgDifficultyLevel::Easy, KgDifficultyLevel::VeryHard
+    KGameDifficulty::global()->addStandardLevelRange(
+        KGameDifficultyLevel::Easy, KGameDifficultyLevel::VeryHard
     );
-    Kg::difficulty()->addLevel(
-                new KgDifficultyLevel(100, QByteArray("Custom"), i18n("Custom"))
+    KGameDifficulty::global()->addLevel(
+                new KGameDifficultyLevel(100, QByteArray("Custom"), i18n("Custom"))
     );
-    KgDifficultyGUI::init(this);
-    connect(Kg::difficulty(), &KgDifficulty::currentLevelChanged, this, &MainWindow::startNewGame);
+    KGameDifficultyGUI::init(this);
+    connect(KGameDifficulty::global(), &KGameDifficulty::currentLevelChanged, this, &MainWindow::startNewGame);
 
 
     setCentralWidget(m_view);
@@ -98,8 +98,8 @@ MainWindow::MainWindow(QWidget *parent)
     m_gameClock = new KGameClock(this, KGameClock::FlexibleHourMinSec);
     connect(m_gameClock, &KGameClock::timeChanged, this, &MainWindow::updateStatusBar);
 
-    m_soundStart = new KgSound(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/start.wav")), this);
-    m_soundWin = new KgSound(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/win.wav")), this);
+    m_soundStart = new KGameSound(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/start.wav")), this);
+    m_soundWin = new KGameSound(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/win.wav")), this);
 
 
     startNewGame();
@@ -108,62 +108,62 @@ MainWindow::MainWindow(QWidget *parent)
 void MainWindow::setupActions()
 {
     // Game
-    KStandardGameAction::gameNew(this, SLOT(startNewGame()),
+    KGameStandardAction::gameNew(this, &MainWindow::startNewGame,
                                  actionCollection());
 
-    m_pauseAction = KStandardGameAction::pause(this, SLOT(pauseGame(bool)),
+    m_pauseAction = KGameStandardAction::pause(this, &MainWindow::pauseGame,
                                                actionCollection());
-    connect(Kg::difficulty(), &KgDifficulty::gameRunningChanged, m_pauseAction,
+    connect(KGameDifficulty::global(), &KGameDifficulty::gameRunningChanged, m_pauseAction,
             &QAction::setEnabled);
 
-    QAction *action = KStandardGameAction::solve(m_view, SLOT(solve()), actionCollection());
-    connect(Kg::difficulty(), &KgDifficulty::gameRunningChanged, action, &QAction::setEnabled);
+    QAction *action = KGameStandardAction::solve(m_view, &GameView::solve, actionCollection());
+    connect(KGameDifficulty::global(), &KGameDifficulty::gameRunningChanged, action, &QAction::setEnabled);
 
-    KStandardGameAction::highscores(this, SLOT(showHighscores()),
+    KGameStandardAction::highscores(this, &MainWindow::showHighscores,
                                     actionCollection());
 
-    KStandardGameAction::quit(this, SLOT(close()), actionCollection());
+    KGameStandardAction::quit(this, &MainWindow::close, actionCollection());
 
     // Settings
-    KStandardAction::preferences(this, SLOT(configureSettings()), actionCollection());
+    KStandardAction::preferences(this, &MainWindow::configureSettings, actionCollection());
 
     action = new QAction(i18n("&Unlock All"), this);
     connect(action, SIGNAL(triggered()), m_view->rootObject(), SLOT(unlockAll()));
-    connect(Kg::difficulty(), &KgDifficulty::gameRunningChanged, action, &QAction::setEnabled);
+    connect(KGameDifficulty::global(), &KGameDifficulty::gameRunningChanged, action, &QAction::setEnabled);
     actionCollection()->addAction( QStringLiteral( "unlock_all" ), action);
 
     action = new QAction(i18n("Keyboard: Field right"), this);
-    actionCollection()->setDefaultShortcut(action, Qt::Key_Right);
+    KActionCollection::setDefaultShortcut(action, Qt::Key_Right);
     connect(action, SIGNAL(triggered()), m_view->rootObject(), SLOT(kbGoRight()));
     actionCollection()->addAction( QStringLiteral( "kb_go_right" ), action);
 
     action = new QAction(i18n("Keyboard: Field left"),this);
-    actionCollection()->setDefaultShortcut(action, Qt::Key_Left);
+    KActionCollection::setDefaultShortcut(action, Qt::Key_Left);
     connect(action, SIGNAL(triggered()), m_view->rootObject(), SLOT(kbGoLeft()));
     actionCollection()->addAction( QStringLiteral( "kb_go_left" ), action);
 
     action = new QAction(i18n("Keyboard: Field up"),this);
-    actionCollection()->setDefaultShortcut(action, Qt::Key_Up);
+    KActionCollection::setDefaultShortcut(action, Qt::Key_Up);
     connect(action, SIGNAL(triggered()), m_view->rootObject(), SLOT(kbGoUp()));
     actionCollection()->addAction( QStringLiteral( "kb_go_up" ), action);
 
     action = new QAction(i18n("Keyboard: Field down"),this);
-    actionCollection()->setDefaultShortcut(action, Qt::Key_Down);
+    KActionCollection::setDefaultShortcut(action, Qt::Key_Down);
     connect(action, SIGNAL(triggered()), m_view->rootObject(), SLOT(kbGoDown()));
     actionCollection()->addAction( QStringLiteral( "kb_go_down" ), action);
 
     action = new QAction(i18n("Keyboard: Turn clockwise"),this);
-    actionCollection()->setDefaultShortcut(action, Qt::Key_Return);
+    KActionCollection::setDefaultShortcut(action, Qt::Key_Return);
     connect(action, SIGNAL(triggered()), m_view->rootObject(), SLOT(rotateClockwise()));
     actionCollection()->addAction( QStringLiteral( "kb_turn_clockwise" ), action);
 
     action = new QAction(i18n("Keyboard: Turn counterclockwise"),this);
-    actionCollection()->setDefaultShortcut(action, Qt::CTRL | Qt::Key_Return);
+    KActionCollection::setDefaultShortcut(action, Qt::CTRL | Qt::Key_Return);
     connect(action, SIGNAL(triggered()), m_view->rootObject(), SLOT(rotateCounterclockwise()));
     actionCollection()->addAction( QStringLiteral( "kb_turn_counterclockwise" ), action);
 
     action = new QAction(i18n("Keyboard: Toggle lock"),this);
-    actionCollection()->setDefaultShortcut(action, Qt::Key_Space);
+    KActionCollection::setDefaultShortcut(action, Qt::Key_Space);
     connect(action, SIGNAL(triggered()), m_view->rootObject(), SLOT(toggleLock()));
     actionCollection()->addAction( QStringLiteral( "kb_lock" ), action);
 }
@@ -174,7 +174,7 @@ void MainWindow::configureSettings()
         return;
     KConfigDialog *dialog = new KConfigDialog(this, QStringLiteral("settings"), Settings::self());
     dialog->addPage(new GeneralConfig(dialog), i18n("General"), QStringLiteral("games-config-options"));
-    dialog->addPage(new KgThemeSelector(m_view->getProvider()), i18n("Theme"), QStringLiteral("games-config-theme"));
+    dialog->addPage(new KGameThemeSelector(m_view->getProvider()), i18n("Theme"), QStringLiteral("games-config-theme"));
     dialog->addPage(new CustomGameConfig(dialog), i18n("Custom Game"), QStringLiteral("games-config-custom"));
     connect(dialog, &KConfigDialog::settingsChanged, m_view, &GameView::updateSettings);
 //    dialog->setHelp(QString(),QLatin1String("knetwalk"));
@@ -185,7 +185,7 @@ void MainWindow::showHighscores()
 {
     KScoreDialog scoreDialog(KScoreDialog::Name | KScoreDialog::Time, this);
     scoreDialog.addField(KScoreDialog::Custom1, i18n("Moves Penalty"), QStringLiteral( "moves" ));
-    scoreDialog.initFromDifficulty(Kg::difficulty());
+    scoreDialog.initFromDifficulty(KGameDifficulty::global());
     scoreDialog.exec();
 }
 
@@ -194,10 +194,10 @@ void MainWindow::startNewGame()
     if(Settings::playSounds())
         m_soundStart->start();
 
-    const KgDifficultyLevel::StandardLevel l = Kg::difficultyLevel();
+    const KGameDifficultyLevel::StandardLevel l = KGameDifficulty::globalLevel();
 
-    bool isWrapped = (l == KgDifficultyLevel::VeryHard);
-    if (Kg::difficultyLevel() == KgDifficultyLevel::Custom)
+    bool isWrapped = (l == KGameDifficultyLevel::VeryHard);
+    if (KGameDifficulty::globalLevel() == KGameDifficultyLevel::Custom)
         isWrapped = Settings::wrapping();
     const QSize size = boardSize();
     m_view->startNewGame(size.width(), size.height(), (Wrapping)isWrapped);
@@ -208,7 +208,7 @@ void MainWindow::startNewGame()
     {
         m_pauseAction->setChecked(false);
     }
-    Kg::difficulty()->setGameRunning(true);
+    KGameDifficulty::global()->setGameRunning(true);
 
     updateStatusBar();
 }
@@ -216,7 +216,7 @@ void MainWindow::startNewGame()
 void MainWindow::gameOver(const QVariant &msg)
 {
     m_gameClock->pause();
-    Kg::difficulty()->setGameRunning(false);
+    KGameDifficulty::global()->setGameRunning(false);
 
     if (msg.toString() != QLatin1String("won"))
         return;
@@ -242,7 +242,7 @@ void MainWindow::gameOver(const QVariant &msg)
     // show the new dialog and add the new score to it
     KScoreDialog scoreDialog(KScoreDialog::Name | KScoreDialog::Time, this);
     scoreDialog.addField(KScoreDialog::Custom1, i18n("Moves Penalty"), QStringLiteral( "moves" ));
-    scoreDialog.initFromDifficulty(Kg::difficulty());
+    scoreDialog.initFromDifficulty(KGameDifficulty::global());
     bool madeIt = scoreDialog.addScore(scoreInfo);
     if (!madeIt) {
         QString comment = i18np("Your score was %1, you did not make it to the high score list.",
@@ -278,11 +278,11 @@ void MainWindow::updateStatusBar()
 
 QSize MainWindow::boardSize()
 {
-    switch (Kg::difficultyLevel()) {
-    case KgDifficultyLevel::Easy: return QSize(5, 5);
-    case KgDifficultyLevel::Medium: return QSize(7, 7);
-    case KgDifficultyLevel::Hard: return QSize(9, 9);
-    case KgDifficultyLevel::Custom: return QSize(Settings::width(), Settings::height());
+    switch (KGameDifficulty::globalLevel()) {
+    case KGameDifficultyLevel::Easy: return QSize(5, 5);
+    case KGameDifficultyLevel::Medium: return QSize(7, 7);
+    case KGameDifficultyLevel::Hard: return QSize(9, 9);
+    case KGameDifficultyLevel::Custom: return QSize(Settings::width(), Settings::height());
     default: return QSize(9, 9);
     }
 }
